pub enum AdRewardType {
AfkInstant,
AfkBoost,
DailyBooster,
UpgradeSpeedup,
FreeAbilityCaseOpen,
FreePetCaseOpen,
DungeonRaid {
dungeon_id: DungeonTemplateId,
difficulty: i64,
},
ArenaRefresh,
ClaimBirdReward {
variant_id: BirdVariantId,
},
}Variants
AfkInstant
AfkBoost
DailyBooster
UpgradeSpeedup
FreeAbilityCaseOpen
FreePetCaseOpen
DungeonRaid
ArenaRefresh
ClaimBirdReward
Fields

variant_id: BirdVariantIdTrait Implementations
Sourceimpl Clone for AdRewardType
impl Clone for AdRewardType
Sourcefn clone(&self) -> AdRewardType
fn clone(&self) -> AdRewardType
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdRewardType
impl Debug for AdRewardType
Sourceimpl<'de> Deserialize<'de> for AdRewardType
impl<'de> Deserialize<'de> for AdRewardType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<AdRewardType> for JsValuewhere
AdRewardType: Serialize,
impl From<AdRewardType> for JsValuewhere
AdRewardType: Serialize,
Sourcefn from(value: AdRewardType) -> Self
fn from(value: AdRewardType) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
impl FromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for AdRewardTypewhere
AdRewardType: Serialize,
impl IntoWasmAbi for AdRewardTypewhere
AdRewardType: Serialize,
Sourceimpl JsonSchema for AdRewardType
impl JsonSchema for AdRewardType
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for AdRewardTypewhere
AdRewardType: Serialize,
impl OptionIntoWasmAbi for AdRewardTypewhere
AdRewardType: Serialize,
Sourceimpl PartialEq for AdRewardType
impl PartialEq for AdRewardType
Sourceimpl RefFromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<AdRewardType>
type Anchor = SelfOwner<AdRewardType>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for AdRewardType
impl Serialize for AdRewardType
Sourceimpl Tsify for AdRewardType
impl Tsify for AdRewardType
const DECL: &'static str = "export type AdRewardType = \"AfkInstant\" | \"AfkBoost\" | \"DailyBooster\" | \"UpgradeSpeedup\" | \"FreeAbilityCaseOpen\" | \"FreePetCaseOpen\" | { DungeonRaid: { dungeon_id: DungeonTemplateId; difficulty: number } } | \"ArenaRefresh\" | { ClaimBirdReward: { variant_id: BirdVariantId } };"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for AdRewardTypewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for AdRewardTypewhere
AdRewardType: Serialize,
impl VectorIntoWasmAbi for AdRewardTypewhere
AdRewardType: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for AdRewardType
impl WasmDescribeVector for AdRewardType
impl Eq for AdRewardType
impl StructuralPartialEq for AdRewardType