pub enum Cheat {
Show 16 variants
PauseCombat,
UnpauseCombat,
GodModeOn,
GodModeOff,
GetRich,
ClearInventory,
ClearSlot {
item_id: Uuid,
},
GetAllSpells,
SetChapter {
chapter: i64,
},
StartFight {
templated_id: FightTemplateId,
},
SpawnEntity {
entity_id: EntityTemplateId,
x: i64,
y: i64,
team: EntityTeam,
attributes: Vec<(String, i64)>,
},
WearItems {
items_ids: Vec<ItemTemplateId>,
},
EquipSkin {
skin_id: SkinId,
},
UnequipSkin {
skin_id: SkinId,
},
NewLevel {
level: i64,
},
Script {
script_id: CheatScriptId,
},
}Variants
PauseCombat
UnpauseCombat
GodModeOn
GodModeOff
GetRich
ClearInventory
ClearSlot
GetAllSpells
SetChapter
StartFight
Fields

templated_id: FightTemplateIdSpawnEntity
WearItems
Fields

items_ids: Vec<ItemTemplateId>EquipSkin
UnequipSkin
NewLevel
Script
Fields

script_id: CheatScriptIdTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Cheat
impl<'de> Deserialize<'de> for Cheat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for Cheatwhere
Self: DeserializeOwned,
impl FromWasmAbi for Cheatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for Cheat
impl IntoWasmAbi for Cheat
Sourceimpl JsonSchema for Cheat
impl JsonSchema for Cheat
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for Cheatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for Cheatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for Cheat
impl OptionIntoWasmAbi for Cheat
Sourceimpl RefFromWasmAbi for Cheatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for Cheatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for Cheat
impl Tsify for Cheat
const DECL: &'static str = "export type Cheat = \"PauseCombat\" | \"UnpauseCombat\" | \"GodModeOn\" | \"GodModeOff\" | \"GetRich\" | \"ClearInventory\" | { ClearSlot: { item_id: Uuid } } | \"GetAllSpells\" | { SetChapter: { chapter: number } } | { StartFight: { templated_id: FightTemplateId } } | { SpawnEntity: { entity_id: EntityTemplateId; x: number; y: number; team: EntityTeam; attributes: [string, number][] } } | { WearItems: { items_ids: ItemTemplateId[] } } | { EquipSkin: { skin_id: SkinId } } | { UnequipSkin: { skin_id: SkinId } } | { NewLevel: { level: number } } | { Script: { script_id: CheatScriptId } };"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for Cheatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for Cheatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for Cheat
impl VectorIntoWasmAbi for Cheat
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
impl Eq for Cheat
impl StructuralPartialEq for Cheat