Enum OverlordEvent

pub enum OverlordEvent {
Show 180 variants OpenItemCase { batch_size: i64, }, AutoChestOpenItemCase { batch_size: i64, }, PlayerNewItems { items: Vec<Item>, }, PlayerEquipItem { item_id: Uuid, }, SellItem { item_id: Uuid, }, ItemSold { item_id: Uuid, }, UpgradeItemCase {}, ItemCaseUpgraded {}, SpeedupUpgradeItemCase {}, SkipUpgradeItemCase {}, ClaimUpgradeItemCase {}, EnableAutoSell {}, DisableAutoSell {}, SetGearOverrideEnabled { item_type: ItemType, enabled: bool, }, EnableAutoChest {}, DisableAutoChest {}, EnableAutoChestFilter { filter_id: AutoChestFilterId, }, DisableAutoChestFilter {}, EnableAutoChestPowerCompare {}, DisableAutoChestPowerCompare {}, UpdateAutoChestBatchSize { batch_size: i64, }, NewAutoChestFilter { filter: AutoChestFilter, }, UpdateAutoChestFilter { updated_filter: AutoChestFilter, }, RemoveAutoChestFilter { filter_id: AutoChestFilterId, }, OpenAbilityCase { roll_type: AbilityCaseRollType, }, SetAbilityGachaWishlist { ability_ids: Vec<AbilityId>, }, UpgradeAbilitySlot { slot_id: u64, }, AbilityCaseOpened { batch_size: u8, }, NewAbilities { abilities: Vec<AbilityDrop>, }, FastEquipAbilities {}, EquipAbility { slot_id: u64, ability_id: AbilityId, }, UnequipAbility { slot_id: AbilitySlotId, }, EquipAbilities { equipped_abilities: EquippedAbilities, }, UpgradeAbility { ability_id: AbilityId, }, UpgradeAllAbilities {}, UpgradedAbilities { upgraded_abilities: UpgradedAbilitiesMap, }, UpgradeAbilityCase {}, CurrencyIncrease { currencies: Vec<CurrencyUnit>, currency_source: CurrencySource, }, CurrencyDecrease { currencies: Vec<CurrencyUnit>, currency_consumer: CurrencyConsumer, }, NewCharacterLevel { level: i64, }, StartGame {}, PrepareFight { prepare_fight_type: PrepareFightType, }, StartFight { fight_id: Uuid, }, FightProgress {}, EndFight { fight_id: Uuid, is_win: bool, pvp_state: Option<PVPState>, }, StageCleared {}, RaidDungeon { dungeon_id: DungeonTemplateId, difficulty: i64, amount: i64, }, WaveCleared {}, StartVassalPVPSync { opponent_id: Uuid, opponent_suzerain_id: Option<Uuid>, }, StartArenaPVPSync { opponent_id: Uuid, is_bot: bool, }, StartArenaRematchSync { match_id: Uuid, }, RefreshArenaMatchmaking {}, BuyArenaTicket {}, StartMove { entity_id: Uuid, to: Coordinates, duration_ticks: u64, }, EndMove { entity_id: Uuid, }, SpawnEntity { id: EntityId, entity_template_id: EntityTemplateId, position: Coordinates, entity_team: EntityTeam, has_big_hp_bar: bool, entity_attributes: EntityAttributes, }, StartCastAbility { by_entity_id: Uuid, ability_id: AbilityId, pet_id: Option<PetId>, }, StartedCastAbility { by_entity_id: Uuid, ability_id: AbilityId, duration_ticks: u64, }, CastAbility { by_entity_id: Uuid, to_entity_id: Uuid, ability_id: AbilityId, }, StartCastProjectile { by_entity_id: Uuid, to_entity_id: Uuid, projectile_id: Uuid, level: i64, delay: u64, }, StartedCastProjectile { by_entity_id: Uuid, to_entity_id: Uuid, projectile_id: Uuid, duration_ticks: u64, }, CastProjectile { by_entity_id: Uuid, to_entity_id: Uuid, projectile_id: Uuid, level: i64, projectile_data: CustomEventData, }, Damage { entity_id: Uuid, damage: u64, damage_data: CustomEventData, }, Heal { entity_id: Uuid, heal: u64, }, CounterAttack { by_entity_id: Uuid, to_entity_id: Uuid, duration_ticks: u64, }, Multicast { entity_id: Uuid, amount: u64, }, Evasion { entity_id: Uuid, }, PlayerDeath {}, EntityDeath { entity_id: Uuid, reward: Vec<CurrencyUnit>, }, EntityIncrAttribute { entity_id: Uuid, attribute: String, delta: i64, }, EntityApplyEffect { entity_id: Uuid, effect_id: Uuid, }, CastEffect { entity_id: Uuid, effect_id: Uuid, }, CastEffectFromEvent { entity_id: Uuid, effect_id: Uuid, caller_event: Box<OverlordEvent>, }, FightCustomEvent { entity_id: u64, value: String, }, FightVisualEvent { effect_type: String, effect_data: CustomEventData, }, SetMaxHp { entity_id: EntityId, new_max_hp: u64, new_hp: u64, }, ClaimVassalReward { character_id: Uuid, }, ClaimSuzerainReward {}, NewSuzerain { new_suzerain: Option<Suzerain>, }, RemoveVassal { vassal_id: Uuid, }, GiveTask { vassal_id: Uuid, template_task_id: Uuid, }, NewTask { new_task: VassalTask, }, AcceptTask { task_id: Uuid, is_good: bool, }, TaskAccepted { task_id: Uuid, started_good: bool, started_at: DateTime<Utc>, finish_at: DateTime<Utc>, }, HitHands { task_id: Uuid, }, HandsHitted { task_id: Uuid, }, TaskFinished { task_id: Uuid, }, ClaimTaskReward { task_id: Uuid, }, GiveResistTask { new_resist_task: VassalTask, }, AcceptResistTask {}, ResistTaskAccepted { new_resist_task: VassalTask, }, CatchResistTask { task_id: Uuid, }, ResistTaskCatched { task_id: Uuid, }, ResistTaskFinished { task_id: Uuid, }, ClaimResistTaskReward { task_id: Uuid, }, SetCustomValue { key: String, value: i64, }, SetConnectionStore { key: String, value: i64, }, ClaimQuest { quest_id: Uuid, }, ClaimAllQuests { quest_group_type: QuestGroupType, }, PatronQuestCompleted { quest_id: Uuid, }, HiddenQuestCompleted { quest_id: Uuid, }, QuestCompleted { quest_id: Uuid, }, NewQuests { quest_ids: Vec<Uuid>, }, UpdateActiveLoopTaskId { quest_id: Uuid, }, ResetRepeatingQuests { quest_ids: Vec<Uuid>, }, ClaimQuestProgressionReward { quest_group_type: QuestGroupType, }, ClaimReferralLvlUpReward { level: i64, }, ClaimReferralDailyReward {}, ReferralDailyRewardStatusUpdate { referral_daily_reward_status: bool, }, SendGift { receiver_id: Uuid, config_gift_id: Uuid, }, NewGift { new_gift: Gift, }, AcceptGift { gift_id: Uuid, }, ClaimAfkReward {}, AfkRewardClaimed {}, AfkRewardsGatingUnlocked {}, ClaimAfkInstantRewardGems {}, WatchAd { ad_reward_type: AdRewardType, }, ShowBird { variant_id: BirdVariantId, }, BirdShown {}, ResetAdUsage { placements: Vec<AdPlacement>, }, ResetInstantRewardGemsPressCount {}, ClaimBundleStepGeneric {}, AddBundleGroup { bundle_ids: Vec<BundleId>, }, ChangeClass { new_class_id: Uuid, }, LinkGuestAccount { token: String, }, SetUsername { username: String, }, SetCharacterBlocked { character_id: Uuid, blocked: bool, }, CreateAbilityPreset { name: Option<String>, ability_ids: Vec<AbilityId>, index: i64, }, EditAbilityPreset { preset_id: AbilityPresetId, name: String, ability_ids: Vec<AbilityId>, }, EnableCaseUpgradePopUp {}, DisableCaseUpgradePopUp {}, BuySkins { skin_ids: Vec<SkinId>, equip: bool, }, EquipAndUnequipSkins { equip_skin_ids: Vec<SkinId>, unequip_skin_ids: Vec<SkinId>, }, RunCheat { cheat: Cheat, }, ClaimMail { mail_id: MailId, }, ClaimAllMails {}, MakeRead { mail_id: MailId, }, MakeAllRead {}, DeleteMail { mail_id: MailId, }, DeleteAllMails {}, NewMail { new_mail: Mail, }, NewOffer { offer_template_id: OfferTemplateId, }, BuyOffer { purchase_token: Option<String>, offer_id: OfferId, }, OfferPurchaseCompleted { purchase_token: String, offer_id: OfferId, }, OfferPurchaseFailed { purchase_token: String, offer_id: OfferId, }, PurchasesBanned {}, ResetOffers { new_offers: Vec<Offer>, }, EquipPet { slot_id: u64, pet_id: PetId, }, UnequipPet { slot_id: PetSlotId, }, FastEquipPets {}, EquipPets { equipped_pets: EquippedPets, }, UpgradePet { pet_id: PetId, }, UpgradeAllPets {}, UpgradedPets { upgraded_pets: UpgradedPetsMap, }, UpgradePetSlot { slot_id: u64, }, OpenPetCase { roll_type: PetCaseRollType, }, SetPetGachaWishlist { pet_ids: Vec<PetId>, }, PetCaseOpened { batch_size: u8, }, NewPets { pets: Vec<PetDrop>, }, UpgradePetCase {}, TutorialShown { step_number: i16, }, TutorialStepCompleted { step_number: i16, }, AddCharacterToParty { character_id: Uuid, }, RemoveCharacterFromParty {}, RefreshPartyPlayers {}, RefreshPartyMemberState {}, StartTalentResearch { talent_id: TalentId, }, TalentResearchStarted { talent_id: TalentId, finish_at: DateTime<Utc>, }, SpeedupTalentResearch {}, SkipTalentResearch {}, ClaimTalentResearch {}, StatueRoll { set_index: u8, locked_slot_indices: Vec<u8>, }, StatueActivateSet { set_index: u8, }, StatueAddSet {}, StatueRenameSet { set_index: u8, name: String, }, StatueLockSlot { set_index: u8, slot_index: u8, is_locked: bool, }, StatueRollNewSlot { set_index: u8, slot_index: u8, }, UserRating { rating: Option<i8>, }, Error { code: String, message: String, }, CustomRhai { event_type: String, data: CustomEventData, },
}

Variants



OpenItemCase

Fields

batch_size: i64


AutoChestOpenItemCase

Fields

batch_size: i64


PlayerNewItems

Fields

items: Vec<Item>


PlayerEquipItem

Fields

item_id: Uuid


SellItem

Fields

item_id: Uuid


ItemSold

Fields

item_id: Uuid


UpgradeItemCase



ItemCaseUpgraded



SpeedupUpgradeItemCase



SkipUpgradeItemCase



ClaimUpgradeItemCase



EnableAutoSell



DisableAutoSell



SetGearOverrideEnabled

Fields

item_type: ItemType
enabled: bool


EnableAutoChest



DisableAutoChest



EnableAutoChestFilter

Fields



DisableAutoChestFilter



EnableAutoChestPowerCompare



DisableAutoChestPowerCompare



UpdateAutoChestBatchSize

Fields

batch_size: i64


NewAutoChestFilter

Fields



UpdateAutoChestFilter

Fields

updated_filter: AutoChestFilter


RemoveAutoChestFilter

Fields



OpenAbilityCase

Fields



SetAbilityGachaWishlist

Обновляет вишлист гачи способностей. Список ограничен числом слотов и разрешенными редкостями текущего уровня гачи.

Fields

ability_ids: Vec<AbilityId>


UpgradeAbilitySlot

Повышает уровень указанного слота способностей за Stardust.

Fields

slot_id: u64


AbilityCaseOpened

Fields

batch_size: u8


NewAbilities

Fields

abilities: Vec<AbilityDrop>


FastEquipAbilities



EquipAbility

Fields

slot_id: u64
ability_id: AbilityId


UnequipAbility

Fields



EquipAbilities

Fields

equipped_abilities: EquippedAbilities


UpgradeAbility

Fields

ability_id: AbilityId


UpgradeAllAbilities



UpgradedAbilities

Fields

upgraded_abilities: UpgradedAbilitiesMap


UpgradeAbilityCase



CurrencyIncrease

Fields

currencies: Vec<CurrencyUnit>
currency_source: CurrencySource


CurrencyDecrease

Fields

currencies: Vec<CurrencyUnit>
currency_consumer: CurrencyConsumer


NewCharacterLevel

Fields

level: i64


StartGame



PrepareFight

Fields

prepare_fight_type: PrepareFightType


StartFight

Fields

fight_id: Uuid


FightProgress



EndFight

Fields

fight_id: Uuid
is_win: bool
pvp_state: Option<PVPState>


StageCleared



RaidDungeon

Fields

difficulty: i64
amount: i64


WaveCleared



StartVassalPVPSync

Fields

opponent_id: Uuid
opponent_suzerain_id: Option<Uuid>


StartArenaPVPSync

Fields

opponent_id: Uuid
is_bot: bool


StartArenaRematchSync

Fields

match_id: Uuid


RefreshArenaMatchmaking



BuyArenaTicket



StartMove

Fields

entity_id: Uuid
duration_ticks: u64


EndMove

Fields

entity_id: Uuid


SpawnEntity

Fields

entity_template_id: EntityTemplateId
position: Coordinates
entity_team: EntityTeam
has_big_hp_bar: bool
entity_attributes: EntityAttributes


StartCastAbility

Fields

by_entity_id: Uuid
ability_id: AbilityId
pet_id: Option<PetId>


StartedCastAbility

Fields

by_entity_id: Uuid
ability_id: AbilityId
duration_ticks: u64


CastAbility

Fields

by_entity_id: Uuid
to_entity_id: Uuid
ability_id: AbilityId


StartCastProjectile

Fields

by_entity_id: Uuid
to_entity_id: Uuid
projectile_id: Uuid
level: i64
delay: u64


StartedCastProjectile

Fields

by_entity_id: Uuid
to_entity_id: Uuid
projectile_id: Uuid
duration_ticks: u64


CastProjectile

Fields

by_entity_id: Uuid
to_entity_id: Uuid
projectile_id: Uuid
level: i64
projectile_data: CustomEventData


Damage

Fields

entity_id: Uuid
damage: u64
damage_data: CustomEventData


Heal

Fields

entity_id: Uuid
heal: u64


CounterAttack

Fields

by_entity_id: Uuid
to_entity_id: Uuid
duration_ticks: u64


Multicast

Fields

entity_id: Uuid
amount: u64


Evasion

Fields

entity_id: Uuid


PlayerDeath



EntityDeath

Fields

entity_id: Uuid


EntityIncrAttribute

Fields

entity_id: Uuid
attribute: String
delta: i64


EntityApplyEffect

Fields

entity_id: Uuid
effect_id: Uuid


CastEffect

Fields

entity_id: Uuid
effect_id: Uuid


CastEffectFromEvent

Fields

entity_id: Uuid
effect_id: Uuid
caller_event: Box<OverlordEvent>


FightCustomEvent

Fields

entity_id: u64
value: String


FightVisualEvent

Fields

effect_type: String
effect_data: CustomEventData


SetMaxHp

Fields

entity_id: EntityId
new_max_hp: u64
new_hp: u64


ClaimVassalReward

Fields

character_id: Uuid


ClaimSuzerainReward



NewSuzerain

Fields

new_suzerain: Option<Suzerain>


RemoveVassal

Fields

vassal_id: Uuid


GiveTask

Fields

vassal_id: Uuid
template_task_id: Uuid


NewTask

Fields

new_task: VassalTask


AcceptTask

Fields

task_id: Uuid
is_good: bool


TaskAccepted

Fields

task_id: Uuid
started_good: bool
started_at: DateTime<Utc>
finish_at: DateTime<Utc>


HitHands

Fields

task_id: Uuid


HandsHitted

Fields

task_id: Uuid


TaskFinished

Fields

task_id: Uuid


ClaimTaskReward

Fields

task_id: Uuid


GiveResistTask

Fields

new_resist_task: VassalTask


AcceptResistTask



ResistTaskAccepted

Fields

new_resist_task: VassalTask


CatchResistTask

Fields

task_id: Uuid


ResistTaskCatched

Fields

task_id: Uuid


ResistTaskFinished

Fields

task_id: Uuid


ClaimResistTaskReward

Fields

task_id: Uuid


SetCustomValue

Fields

value: i64


SetConnectionStore

Fields

value: i64


ClaimQuest

Fields

quest_id: Uuid


ClaimAllQuests

Fields

quest_group_type: QuestGroupType


PatronQuestCompleted

Fields

quest_id: Uuid


HiddenQuestCompleted

Fields

quest_id: Uuid


QuestCompleted

Fields

quest_id: Uuid


NewQuests

Fields

quest_ids: Vec<Uuid>


UpdateActiveLoopTaskId

Fields

quest_id: Uuid


ResetRepeatingQuests

Fields

quest_ids: Vec<Uuid>


ClaimQuestProgressionReward

Fields

quest_group_type: QuestGroupType


ClaimReferralLvlUpReward

Fields

level: i64


ClaimReferralDailyReward



ReferralDailyRewardStatusUpdate

Fields

referral_daily_reward_status: bool


SendGift

Fields

receiver_id: Uuid
config_gift_id: Uuid


NewGift

Fields

new_gift: Gift


AcceptGift

Fields

gift_id: Uuid


ClaimAfkReward



AfkRewardClaimed



AfkRewardsGatingUnlocked

Emitted when the player crosses the AFK rewards unlock chapter threshold and the async handler has adjusted last_afk_reward_claimed_at so that the elapsed time is not less than min_required_time_sec. The side effect handler persists the new value to the database.



ClaimAfkInstantRewardGems



WatchAd

Fields

ad_reward_type: AdRewardType


ShowBird

Fields

variant_id: BirdVariantId


BirdShown

Отправляется клиентом, когда птица была успешно показана игроку. Переводит птицу в полный кулдаун.



ResetAdUsage

Fields

placements: Vec<AdPlacement>


ResetInstantRewardGemsPressCount



ClaimBundleStepGeneric



AddBundleGroup

Fields

bundle_ids: Vec<BundleId>


ChangeClass

Fields

new_class_id: Uuid


LinkGuestAccount

Fields

token: String


SetUsername

Fields

username: String


SetCharacterBlocked

Fields

character_id: Uuid
blocked: bool


CreateAbilityPreset

Fields

ability_ids: Vec<AbilityId>
index: i64


EditAbilityPreset

Fields

name: String
ability_ids: Vec<AbilityId>


EnableCaseUpgradePopUp



DisableCaseUpgradePopUp



BuySkins

Fields

skin_ids: Vec<SkinId>
equip: bool


EquipAndUnequipSkins

Fields

equip_skin_ids: Vec<SkinId>
unequip_skin_ids: Vec<SkinId>


RunCheat

Fields

cheat: Cheat


ClaimMail

Fields

mail_id: MailId


ClaimAllMails



MakeRead

Fields

mail_id: MailId


MakeAllRead



DeleteMail

Fields

mail_id: MailId


DeleteAllMails



NewMail

Fields

new_mail: Mail


NewOffer

Fields

offer_template_id: OfferTemplateId


BuyOffer

Fields

purchase_token: Option<String>
offer_id: OfferId


OfferPurchaseCompleted

Fields

purchase_token: String
offer_id: OfferId


OfferPurchaseFailed

Fields

purchase_token: String
offer_id: OfferId


PurchasesBanned



ResetOffers

Fields

new_offers: Vec<Offer>


EquipPet

Fields

slot_id: u64
pet_id: PetId


UnequipPet

Fields

slot_id: PetSlotId


FastEquipPets



EquipPets

Fields

equipped_pets: EquippedPets


UpgradePet

Fields

pet_id: PetId


UpgradeAllPets



UpgradedPets

Fields

upgraded_pets: UpgradedPetsMap


UpgradePetSlot

Fields

slot_id: u64


OpenPetCase

Fields



SetPetGachaWishlist

Обновляет вишлист гачи петов.

Fields

pet_ids: Vec<PetId>


PetCaseOpened

Fields

batch_size: u8


NewPets

Fields

pets: Vec<PetDrop>


UpgradePetCase



TutorialShown

Fields

step_number: i16


TutorialStepCompleted

Fields

step_number: i16


AddCharacterToParty

Fields

character_id: Uuid


RemoveCharacterFromParty



RefreshPartyPlayers



RefreshPartyMemberState



StartTalentResearch

Начать изучение следующего уровня таланта (клиент -> бэкенд).

Fields

talent_id: TalentId


TalentResearchStarted

Бэкенд подтверждает начало изучения таланта.

Fields

talent_id: TalentId
finish_at: DateTime<Utc>


SpeedupTalentResearch

Ускорить изучение таланта с помощью таймскип-билетика.



SkipTalentResearch

Пропустить оставшееся время изучения за валюту (брюли/таймскипы).



ClaimTalentResearch

Забрать завершённый талант (после истечения таймера). Эмитируется бэкендом автоматически.



StatueRoll

Откатить незаблокированные слоты статуи. Списывает валюту, начисляет опыт статуе.

Fields

set_index: u8
locked_slot_indices: Vec<u8>


StatueActivateSet

Сделать указанный сет статуи активным (“In Use”).

Fields

set_index: u8


StatueAddSet

Добавить новый сет статуи (если уровень статуи позволяет).



StatueRenameSet

Переименовать сет статуи.

Fields

set_index: u8
name: String


StatueLockSlot

Заблокировать или разблокировать слот статуи.

Fields

set_index: u8
slot_index: u8
is_locked: bool


StatueRollNewSlot

Бесплатный первичный ролл для нового слота на любом сете (после создания сета или повышения уровня статуи).

Fields

set_index: u8
slot_index: u8


UserRating

User rated the game (1–5) or declined to rate (rating = None).

Fields

rating: Option<i8>


Error

Fields

code: String
message: String


CustomRhai

Fields

event_type: String