pub enum PrepareFightType {
PVEFight,
PVPFight {
fight_id: FightTemplateId,
pvp_state: Box<PVPState>,
},
RetryBossFight,
DungeonFight {
dungeon_id: DungeonTemplateId,
difficulty: i64,
},
ForfeitDungeonFight,
SingleFight {
fight_templated_id: FightTemplateId,
},
}Variants
PVEFight
PVPFight
RetryBossFight
DungeonFight
ForfeitDungeonFight
SingleFight
Fields

fight_templated_id: FightTemplateIdTrait Implementations
Sourceimpl Clone for PrepareFightType
impl Clone for PrepareFightType
Sourcefn clone(&self) -> PrepareFightType
fn clone(&self) -> PrepareFightType
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareFightType
impl Debug for PrepareFightType
Sourceimpl<'de> Deserialize<'de> for PrepareFightType
impl<'de> Deserialize<'de> for PrepareFightType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<PrepareFightType> for JsValuewhere
PrepareFightType: Serialize,
impl From<PrepareFightType> for JsValuewhere
PrepareFightType: Serialize,
Sourcefn from(value: PrepareFightType) -> Self
fn from(value: PrepareFightType) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
impl FromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for PrepareFightTypewhere
PrepareFightType: Serialize,
impl IntoWasmAbi for PrepareFightTypewhere
PrepareFightType: Serialize,
Sourceimpl JsonSchema for PrepareFightType
impl JsonSchema for PrepareFightType
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for PrepareFightTypewhere
PrepareFightType: Serialize,
impl OptionIntoWasmAbi for PrepareFightTypewhere
PrepareFightType: Serialize,
Sourceimpl PartialEq for PrepareFightType
impl PartialEq for PrepareFightType
Sourceimpl RefFromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
impl RefFromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<PrepareFightType>
type Anchor = SelfOwner<PrepareFightType>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for PrepareFightType
impl Serialize for PrepareFightType
Sourceimpl Tsify for PrepareFightType
impl Tsify for PrepareFightType
const DECL: &'static str = "export type PrepareFightType = \"PVEFight\" | { PVPFight: { fight_id: FightTemplateId; pvp_state: PVPState } } | \"RetryBossFight\" | { DungeonFight: { dungeon_id: DungeonTemplateId; difficulty: number } } | \"ForfeitDungeonFight\" | { SingleFight: { fight_templated_id: FightTemplateId } };"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for PrepareFightTypewhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for PrepareFightTypewhere
PrepareFightType: Serialize,
impl VectorIntoWasmAbi for PrepareFightTypewhere
PrepareFightType: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for PrepareFightType
impl WasmDescribeVector for PrepareFightType
impl Eq for PrepareFightType
impl StructuralPartialEq for PrepareFightType